pub struct ConsentRequest {
pub message: String,
pub reply: Sender<bool>,
}Expand description
A consent question travelling from the component actor task to the MCP request handler task, with the channel to answer it on.
Fields
message: Stringreply: Sender<bool>Auto Trait Implementations
impl !RefUnwindSafe for ConsentRequest
impl !UnwindSafe for ConsentRequest
impl Freeze for ConsentRequest
impl Send for ConsentRequest
impl Sync for ConsentRequest
impl Unpin for ConsentRequest
impl UnsafeUnpin for ConsentRequest