create_mount_dirs

Function create_mount_dirs 

pub fn create_mount_dirs(mounts: &[ResolvedMount]) -> Result<()>
Create missing bind host directories so they can be preopened. root mounts point at the platform root and create nothing.