pub struct ActWorld { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world act-world.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
ActWorld::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
ActWorldPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesActWorldPre::instantiateto create aActWorld. -
If you’ve instantiated the instance yourself already then you can use
ActWorld::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl ActWorld
impl ActWorld
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ActWorld>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<ActWorld>
Convenience wrapper around ActWorldPre::new and
ActWorldPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<ActWorld>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<ActWorld>
Convenience wrapper around ActWorldIndices::new and
ActWorldIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ActWorld>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ActWorld>where
_T: Send,
Convenience wrapper around ActWorldPre::new and
ActWorldPre::instantiate_async.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> D::Data<'_>,
) -> Result<()>where
D: HostWithStore<T> + HostWithStore<T> + HostWithStore<T> + HostWithStore<T> + HostWithStore<T> + HostWithStore<T> + HostWithStore<T> + Send,
for<'a> D::Data<'a>: Host + Host + Host + Host + Host + Host + Host + Send,
T: 'static + Send,
pub fn act_tools_tool_provider(&self) -> &Guest
pub fn act_sessions_session_provider(&self) -> &Guest