pub fn create_mount_dirs(mounts: &[ResolvedMount]) -> Result<()>Expand description
Create missing bind host directories so they can be preopened. root
mounts point at the platform root and create nothing.
pub fn create_mount_dirs(mounts: &[ResolvedMount]) -> Result<()>Create missing bind host directories so they can be preopened. root
mounts point at the platform root and create nothing.